@@ -18,11 +18,16 @@ pub fn add_five(x: i32) -> i32 {
     x + 5
 }
 
+pub fn add_six(x: i32) -> i32 {
+    x + 6
+}
+
 #[cfg(test)]
 mod tests {
     use super::add_five;
     use super::add_four;
     use super::add_one;
+    use super::add_six;
     use super::add_three;
     use super::add_two;
 
@@ -50,4 +55,9 @@ mod tests {
     fn should_add_five() {
         assert_eq!(6, add_five(1));
     }
+
+    #[test]
+    fn should_add_six() {
+        assert_eq!(7, add_six(1));
+    }
 }
